@@ -8,7 +8,8 @@ from typing import OrderedDict
 
 from expressmoney.api import PointNotFound404, PointThrottled, PointClientError, PointServerError
 from expressmoney.api.point import PointError
-from expressmoney.utils import status
+from rest_framework import status
+
 from .contract import Contract
 from .id import ID
 from .client import Request
@@ -22,7 +23,6 @@ class Point:
                  user,
                  timeout: tuple = (30, 30)
                  ):
-        self._user = user
         self._response = None
         self._client = Request(service=self._point_id.service,
                                path=self._path,
@@ -30,6 +30,10 @@ class Point:
                                timeout=timeout,
                                )
 
+    @property
+    def client(self):
+        return self._client
+
     @property
     def _path(self):
         path = self._point_id.path
@@ -49,7 +53,7 @@ class Point:
 
         if not status.is_success(response.status_code):
             if status.is_client_error(response.status_code):
-                if status.is_not_found(response.status_code):
+                if response.status_code == status.HTTP_404_NOT_FOUND:
                     raise PointNotFound404(self._client.url)
                 if response.status_code == status.HTTP_429_TOO_MANY_REQUESTS:
                     raise PointThrottled(self._client.url, response.status_code, response.headers.get(
