@@ -1,4 +1,6 @@
-__all__ = ('NoLoanPoint',)
+__all__ = ('NoLoanPoint', 'SmsPoint')
+
+from phonenumber_field.serializerfields import PhoneNumberField
 
 from expressmoney_service.api import *
 
@@ -11,8 +13,9 @@ class _NoLoanCreateContract(Contract):
     passport_number = serializers.CharField(max_length=6)
 
 
-class _NoLoanResponseContract(Contract):
-    is_no_loan = serializers.BooleanField()
+class _SmsCreateContract(Contract):
+    phonenumber = PhoneNumberField()
+    message = serializers.CharField(max_length=60)
 
 
 class _NoLoanID(ID):
@@ -21,7 +24,17 @@ class _NoLoanID(ID):
     _view_set = 'no_loan'
 
 
-class NoLoanPoint(ResponseMixin, CreatePointMixin, ContractPoint):
+class _SmsID(ID):
+    _service = _SERVICE
+    _app = _APP
+    _view_set = 'sms'
+
+
+class NoLoanPoint(CreatePointMixin, ContractPoint):
     _point_id = _NoLoanID()
     _create_contract = _NoLoanCreateContract
-    _response_contract = _NoLoanResponseContract
+
+
+class SmsPoint(CreatePointMixin, ContractPoint):
+    _point_id = _SmsID()
+    _create_contract = _SmsCreateContract
